@@ -1,3 +1,8 @@
+"""
+`xr` is the top level module of the pyopenxr unofficial python bindings for the
+OpenXR SDK to access VR and AR devices.
+"""
+
 from . import (
     version,
     constants,
@@ -11,6 +16,7 @@ from . import (
     context_object,
     opengl_graphics,
     matrix4x4f,
+    extension,
 )
 
 from .version import *
@@ -26,8 +32,6 @@ from .context_object import *
 from .opengl_graphics import *
 from .matrix4x4f import *
 
-# Use submodule name for extension
-import xr.extension as extension
 
 # from .experiment import *
 
